@@ -16,7 +16,7 @@
 #'   * `"rollmedian"`: rolling meadian
 #'   * `"savgol"`:  Savitzky-Golay filtering
 #'
-#'   All methods but "lowess" ignore non-equidistant arg values.
+#'   All methods but `"lowess"` ignore non-equidistant arg values.
 #' * `args` :: named `list()`\cr
 #'   List of named arguments that is passed to `tf_smooth()`. See the help page of `tf_smooth()` for
 #'   default values.
@@ -37,7 +37,7 @@ PipeOpFDASmooth = R6Class("PipeOpFDASmooth",
     #' @description Initializes a new instance of this Class.
     #' @param id (`character(1)`)\cr
     #'   Identifier of resulting object, default `"fda.smooth"`.
-    #' @param param_vals (named `list`)\cr
+    #' @param param_vals (named `list()`)\cr
     #'   List of hyperparameter settings, overwriting the hyperparameter settings that would
     #'   otherwise be set during construction. Default `list()`.
     initialize = function(id = "fda.smooth", param_vals = list()) {
@@ -66,17 +66,21 @@ PipeOpFDASmooth = R6Class("PipeOpFDASmooth",
       pars = self$param_set$get_values()
 
       if (pars$verbose) {
-        map_dtc(dt, function(x) {
-          invoke(tf::tf_smooth, x = x, method = pars$method, .args = pars$args)
-        })
-      } else {
-        map_dtc(dt, function(x) {
-          suppressMessages(invoke(tf::tf_smooth, x = x, method = pars$method, .args = pars$args))
-        })
+        for (j in seq_along(dt)) {
+          set(dt, j = j, value = invoke(tf::tf_smooth, x = dt[[j]], method = pars$method, .args = pars$args))
+        }
+        return(dt)
       }
-
+      for (j in seq_along(dt)) {
+        set(dt,
+          j = j,
+          value = suppressMessages(invoke(tf::tf_smooth, x = dt[[j]], method = pars$method, .args = pars$args))
+        )
+      }
+      dt
     }
   )
 )
+
 #' @include zzz.R
 register_po("fda.smooth", PipeOpFDASmooth)
