@@ -5,17 +5,16 @@
 #' This `PipeOp` applies a functional principal component analysis (FPCA) to functional columns and then
 #' extracts the principal components as features. This is done using a (truncated) weighted SVD.
 #'
-#' To apply this `PipeOp` to irregualr data, convert it to a regular grid first using [`PipeOpFDAInterpol`].
+#' To apply this `PipeOp` to irregular data, convert it to a regular grid first using [`PipeOpFDAInterpol`].
 #'
 #' For more details, see [tf::tfb_fpc()], which is called internally.
 #'
-#'
 #' @section Parameters:
 #' The parameters are the parameters inherited from [`PipeOpTaskPreproc`][mlr3pipelines::PipeOpTaskPreproc],
 #' as well as the following parameters:
-#' * `pve` :: `numeric(1)` \cr
+#' * `pve` :: `numeric(1)`\cr
 #'   The percentage of variance explained that should be retained. Default is `0.995`.
-#' * `n_components` :: `integer(1)` \cr
+#' * `n_components` :: `integer(1)`\cr
 #'   The number of principal components to extract. This parameter is initialized to `Inf`.
 #'
 #' @section Naming:
@@ -35,7 +34,7 @@ PipeOpFPCA = R6Class("PipeOpFPCA",
     #' @description Initializes a new instance of this Class.
     #' @param id (`character(1)`)\cr
     #'   Identifier of resulting object, default is `"fda.fpca"`.
-    #' @param param_vals (named `list`)\cr
+    #' @param param_vals (named `list()`)\cr
     #'   List of hyperparameter settings, overwriting the hyperparameter settings that would
     #'   otherwise be set during construction. Default `list()`.
     initialize = function(id = "fda.fpca", param_vals = list()) {
@@ -67,7 +66,7 @@ PipeOpFPCA = R6Class("PipeOpFPCA",
       dt = imap_dtc(dt, function(col, nm) {
         map(col, function(x) {
           pc = as.list(x[2:min(pars$n_components + 1L, length(x))])
-          set_names(pc, sprintf("%s_pc_%d", nm, seq_along(pc)))
+          set_names(pc, sprintf("%s_pc_%i", nm, seq_along(pc)))
         })
       })
       unnest(dt, names(dt))
@@ -85,7 +84,7 @@ PipeOpFPCA = R6Class("PipeOpFPCA",
         )
         map(fpc, function(x) {
           pc = as.list(x[2:min(pars$n_components + 1L, length(x))])
-          set_names(pc, sprintf("%s_pc_%d", nm, seq_along(pc)))
+          set_names(pc, sprintf("%s_pc_%i", nm, seq_along(pc)))
         })
       })
       unnest(dt, names(dt))
