@@ -7,4 +7,8 @@ library(paradox)
 
 walk(list.files(system.file("testthat", package = "mlr3"), pattern = "^helper.*\\.[rR]", full.names = TRUE), source)
 # filter out helper_compat.R for weird reason to overload testthat functions to v2 behavior
-map_if(list.files(system.file("testthat", package = "mlr3pipelines"), pattern = "^helper.*\\.[rR]", full.names = TRUE), function(x) !endsWith(x, "helper_compat.R"), source)
+map_if(
+  list.files(system.file("testthat", package = "mlr3pipelines"), pattern = "^helper.*\\.[rR]", full.names = TRUE),
+  function(x) !endsWith(x, "helper_compat.R"),
+  source
+)
